Bifrost: src/ColorSet.hpp File Reference

Bifrost

Data Structures
ColorSet.hpp File Reference

Interface for UnitigColors, the unitig container of k-mer color sets used in ColoredCDBG. More...

Go to the source code of this file.

## Data Structures
class | ColoredCDBG< Unitig_data_t >
| Represent a Colored and Compacted de Bruijn graph. More...
class | DataAccessor< Unitig_data_t >
| Interface to access the colors and the data associated with a unitig of a ColoredCDBG. More...
class | DataStorage< Unitig_data_t >
class | UnitigColors
| Represent the k-mer color sets of a unitig. More...
class | UnitigColors::UnitigColors_const_iterator
| See UnitigColors::const_iterator. More...
struct | UnitigColorsHash

## Detailed Description

Interface for UnitigColors, the unitig container of k-mer color sets used in ColoredCDBG.

Code snippets using this interface are provided in snippets/test.cpp.